@@ -20,11 +20,14 @@ The examples below assume the following in appname/models.py::
 """
 
 import datetime as dt
+from contextlib import suppress
 
 import pytz
 from django.contrib import admin
+from django.contrib.humanize.templatetags.humanize import naturaltime
 from django.db import models, transaction
-from django.db.models import F
+from django.db.models import F, IntegerField
+from django.db.models.functions import Floor
 
 ONE_HOUR = dt.timedelta(hours=1)
 ZERO_SECS = dt.timedelta(seconds=0)
@@ -266,7 +269,7 @@ class Status(int):
         assert len(result) == 19
         return Status(result)
 
-    def parse(self, datetime=True):
+    def parse(self):
         """Parse status into state, priority, and attempts fields.
 
         If `datetime` is True (the default), then parse priority into datetime
@@ -293,27 +296,32 @@ class Status(int):
         >>> attempts
         5
         >>> status = Status(3000000000000000007)
-        >>> status.parse(datetime=False)
+        >>> status.parse()
         (State(3, 'working'), 0, 7)
 
         """
         priority = self.priority
-        if datetime:
-            priority = str(priority)
+        timestamp = str(priority)
+        with suppress(ValueError):
             priority = dt.datetime(
-                year=int(priority[0:4]),
-                month=int(priority[4:6]),
-                day=int(priority[6:8]),
-                hour=int(priority[8:10]),
-                minute=int(priority[10:12]),
-                second=int(priority[12:14]),
-                microsecond=int(priority[14:17]) * 1000,
+                year=int(timestamp[0:4]),
+                month=int(timestamp[4:6]),
+                day=int(timestamp[6:8]),
+                hour=int(timestamp[8:10]),
+                minute=int(timestamp[10:12]),
+                second=int(timestamp[12:14]),
+                microsecond=int(timestamp[14:17]) * 1000,
                 tzinfo=pytz.utc,
             )
         return self.state, priority, self.attempts
 
     def __str__(self):
-        return str(int(self))
+        state, when, attempts = self.parse()
+        if isinstance(when, dt.datetime):
+            when = naturaltime(when)
+        else:
+            when = '%s priority' % when
+        return f'{state.name}; {when}; {attempts} attempts'
 
     def __repr__(self):
         type_name = type(self).__name__
@@ -418,7 +426,7 @@ def run(queryset, field, action, retry=3, timeout=ONE_HOUR, delay=ZERO_SECS):
                         time.sleep(1)
                         # ^-- Bring your own parallelism/concurrency.
 
-            def process(self, report):
+            def process(self, task):
                 pass  # Process task models.
 
     :param queryset: Django queryset
@@ -518,9 +526,10 @@ def admin_actions(field):
     :returns: Django admin actions
 
     """
+    display_name = field.replace('_', ' ')
 
     def make_action(state):
-        @admin.action(description=f'Change {field} state to {state}')
+        @admin.action(description=f'Change {display_name} state to {state}')
         def make_state(modeladmin, request, queryset):
             # pylint: disable=unused-argument
             offset = Status.state_offset
@@ -533,13 +542,15 @@ def admin_actions(field):
     actions = []
     actions.extend(map(make_action, Status.states))
 
-    @admin.action(description=f'Change {field} priority to now')
+    @admin.action(description=f'Change {display_name} priority to now')
     def make_priority_now(modeladmin, request, queryset):
         # pylint: disable=unused-argument
         offset = Status.state_offset
         priority = datetime_to_int(now())
         calculation = (
-            F(field) / offset * offset + priority * 10 + F(field) % 10
+            Floor(F(field) / offset, output_field=IntegerField()) * offset
+            + priority * 10
+            + F(field) % 10
         )
         kwargs = {field: calculation}
         queryset.update(**kwargs)
@@ -547,10 +558,12 @@ def admin_actions(field):
     make_priority_now.__name__ = f'make_{field}_priority_now'
     actions.append(make_priority_now)
 
-    @admin.action(description=f'Change {field} attempts to zero')
+    @admin.action(description=f'Change {display_name} attempts to zero')
     def make_attempts_zero(modeladmin, request, queryset):
         # pylint: disable=unused-argument
-        kwargs = {field: F(field) / 10 * 10}
+        kwargs = {
+            field: Floor(F(field) / 10, output_field=IntegerField()) * 10
+        }
         queryset.update(**kwargs)
 
     make_attempts_zero.__name__ = f'make_{field}_attempts_zero'
@@ -574,19 +587,23 @@ def admin_list_filter(field):
 
     """
 
+    display_name = field[:-6] if field.endswith('status') else field
+    display_name = display_name.replace('_', ' ').strip()
+    filter_title = ('%s queue status' % display_name).strip()
+
     class QueueFilter(admin.SimpleListFilter):
         """Django admin ModelQueue list filter."""
 
-        title = '%s queue status' % field
+        title = filter_title
         parameter_name = '%s_queue' % field
 
         def lookups(self, request, model_admin):
             return (
-                (State.created, 'Created (1)'),
-                (State.waiting, 'Waiting (2)'),
-                (State.working, 'Working (3)'),
-                (State.finished, 'Finished (4)'),
-                (State.canceled, 'Canceled (5)'),
+                (State.created, 'Created'),
+                (State.waiting, 'Waiting'),
+                (State.working, 'Working'),
+                (State.finished, 'Finished'),
+                (State.canceled, 'Canceled'),
             )
 
         def queryset(self, request, queryset):
@@ -603,8 +620,8 @@ def admin_list_filter(field):
 
 
 __title__ = 'modelqueue'
-__version__ = '2.0.0'
-__build__ = 0x020000
+__version__ = '2.2.1'
+__build__ = 0x020201
 __author__ = 'Grant Jenks'
 __license__ = 'Apache 2.0'
 __copyright__ = 'Copyright 2022 Grant Jenks'
